@@ -8,6 +8,7 @@ from unittest.mock import patch
 
 import humanize
 import pytest
+from test_run_manager_class import prepare_config_file
 from test_telegram_reporter_class import SessionReplacement
 
 import lip_pps_run_manager as RM
@@ -80,6 +81,7 @@ def test_init_bad_type_path():
     try:
         task_name = "testTask"
         RM.TaskManager("/bad/path", task_name, drop_old_data=True, script_to_backup=None)
+        raise Exception("Passed through a fail condition without failing")  # pragma: no cover
     except TypeError as e:
         assert str(e) == "The `path_to_run` must be a Path type object, received object of type <class 'str'>"
 
@@ -91,6 +93,7 @@ def test_init_bad_type_name():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=True, script_to_backup=None)
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except TypeError as e:
             assert str(e) == "The `task_name` must be a str type object, received object of type <class 'int'>"
 
@@ -102,6 +105,7 @@ def test_init_bad_type_drop_old_data():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=1, script_to_backup=None)
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except TypeError as e:
             assert str(e) == "The `drop_old_data` must be a bool type object, received object of type <class 'int'>"
 
@@ -113,6 +117,7 @@ def test_init_bad_type_script_to_backup():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=True, script_to_backup=1)
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except TypeError as e:
             assert str(e) == "The `script_to_backup` must be a Path type object or None, received object of type <class 'int'>"
 
@@ -124,6 +129,7 @@ def test_init_bad_type_telegram_bot_token():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=True, script_to_backup=None, telegram_bot_token=2)
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except TypeError as e:
             assert str(e) == "The `telegram_bot_token` must be a str type object or None, received object of type <class 'int'>"
 
@@ -135,6 +141,7 @@ def test_init_bad_type_telegram_chat_id():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=True, script_to_backup=None, telegram_chat_id=2)
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except TypeError as e:
             assert str(e) == "The `telegram_chat_id` must be a str type object or None, received object of type <class 'int'>"
 
@@ -146,6 +153,7 @@ def test_init_bad_type_loop_iterations():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=True, script_to_backup=None, loop_iterations="2")
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except TypeError as e:
             assert str(e) == "The `loop_iterations` must be a int type object or None, received object of type <class 'str'>"
 
@@ -157,6 +165,7 @@ def test_init_bad_type_minimum_update_time_seconds():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=True, script_to_backup=None, minimum_update_time_seconds="2")
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except TypeError as e:
             assert str(e) == "The `minimum_update_time_seconds` must be a int type object, received object of type <class 'str'>"
 
@@ -168,6 +177,7 @@ def test_init_bad_type_minimum_warn_time_seconds():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=True, script_to_backup=None, minimum_warn_time_seconds="2")
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except TypeError as e:
             assert str(e) == "The `minimum_warn_time_seconds` must be a int type object, received object of type <class 'str'>"
 
@@ -179,6 +189,7 @@ def test_init_bad_run_directory():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=True, script_to_backup=None)
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except RuntimeError as e:
             assert str(e) == "The 'path_to_run' ({}) does not look like the directory of a run...".format(handler.run_path)
 
@@ -190,6 +201,7 @@ def test_init_no_script_to_backup():
 
         try:
             RM.TaskManager(handler.run_path, task_name, drop_old_data=True, script_to_backup=handler.run_path)
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except RuntimeError as e:
             assert str(e) == "The 'script_to_backup', if set, must point to a file. It points to: {}".format(handler.run_path)
 
@@ -212,7 +224,7 @@ def test_init_loop_iterations():
 
 
 @patch('requests.Session', new=SessionReplacement)  # To avoid sending actual http requests
-def test_repr_with_bot():
+def test_repr_with_bot_ids():
     with PrepareRunDir() as handler:
         task_name = "testTask"
         drop_old_data = True
@@ -257,6 +269,57 @@ def test_repr_with_bot():
         )
 
 
+@patch('requests.Session', new=SessionReplacement)  # To avoid sending actual http requests
+def test_repr_with_bot_names():
+    with PrepareRunDir() as handler:
+        task_name = "testTask"
+        drop_old_data = True
+        script_to_backup = None
+        loop_iterations = 30
+        minimum_update_time_seconds = 60
+        minimum_warn_time_seconds = 60
+        bot_name = "bot_name"
+        chat_name = "chat_name"
+        bot_token = "bot_token"
+        chat_id = "chat_id"
+        rate_limit = False
+        config_file = prepare_config_file(bot_name, bot_token, chat_name, chat_id)
+
+        Tobias = RM.TaskManager(
+            handler.run_path,
+            task_name,
+            drop_old_data=drop_old_data,
+            script_to_backup=script_to_backup,
+            loop_iterations=loop_iterations,
+            minimum_update_time_seconds=minimum_update_time_seconds,
+            minimum_warn_time_seconds=minimum_warn_time_seconds,
+            telegram_bot_name=bot_name,
+            telegram_chat_name=chat_name,
+            rate_limit=rate_limit,
+        )
+
+        assert repr(Tobias) == (
+            "TaskManager({}, {}, drop_old_data={}, "
+            "script_to_backup={}, telegram_bot_name={}, "
+            "telegram_chat_name={}, loop_iterations={}, "
+            "minimum_update_time_seconds={}, "
+            "minimum_warn_time_seconds={}, rate_limit={})".format(
+                repr(handler.run_path),
+                repr(task_name),
+                repr(drop_old_data),
+                repr(script_to_backup),
+                repr(bot_name),
+                repr(chat_name),
+                repr(loop_iterations),
+                repr(minimum_update_time_seconds),
+                repr(minimum_warn_time_seconds),
+                repr(rate_limit),
+            )
+        )
+
+        config_file.unlink()
+
+
 @patch('requests.Session', new=SessionReplacement)  # To avoid sending actual http requests
 def test_repr_no_bot():
     with PrepareRunDir() as handler:
@@ -368,6 +431,7 @@ def test_loop_tick_outside_context():
 
         try:
             Tobias.loop_tick()
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except RuntimeError as e:
             assert str(e) == ("Tried calling loop_tick() while not inside a task context. Use the 'with TaskManager as handle' syntax")
 
@@ -466,6 +530,7 @@ def test_set_completed_outside_context():
 
         try:
             Tobias.set_completed()
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except RuntimeError as e:
             assert str(e) == ("Tried calling set_completed() while not inside a task context. Use the 'with TaskManager as handle' syntax")
 
@@ -540,6 +605,7 @@ def test_update_status_outside_context():
 
         try:
             Tobias._update_status()
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except RuntimeError as e:
             assert str(e) == ("Tried calling _update_status() while not inside a task context. Use the 'with TaskManager as handle' syntax")
 
@@ -868,7 +934,8 @@ def test_enter_double_entry():
 
         try:
             with Tobias:
-                pass
+                pass  # pragma: no cover
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except RuntimeError as e:
             assert str(e) == "Once a task has processed its data, it can not be processed again. Use a new task"
 
@@ -1237,6 +1304,7 @@ def test_exit_backup_file_does_not_exist():
                 rate_limit=rate_limit,
             ) as Tobias:
                 Tobias._script_to_backup = handler.run_path
+                raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except RuntimeError as e:
             assert str(e) == "Somehow you are trying to backup a file that does not exist"
 
@@ -1338,6 +1406,7 @@ def test_warn_bad_type_message():
 
         try:
             Tobias.warn(2)
+            raise Exception("Passed through a fail condition without failing")  # pragma: no cover
         except TypeError as e:
             assert str(e) == "The `message` must be a str type object, received object of type <class 'int'>"
 
